@@ -354,13 +354,13 @@ These are the ones I use every day so they may be a good start:
 
 =back
 
-=over4
+=over 4
 
 =item * Go to Version Control
 
 =back
 
-=over4
+=over 4
 
 =item * Find with Ack
 
@@ -368,7 +368,7 @@ These are the ones I use every day so they may be a good start:
 
 =back
 
-=over4
+=over 4
 
 =item * Run tests, Re-run tests
 
@@ -571,7 +571,7 @@ development.
 The search takes place from the Project directory. Before running ack
 you'll get to edit the command line with a sensible default chosen from:
 
-=over4
+=over 4
 
 =item * the active region
 
@@ -1535,9 +1535,15 @@ L<http://vimdoc.sourceforge.net/htmldoc/eval.html#Dictionaries> - Vim native dat
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrm, C<< <johanl buzzwordninja.com> >>
+
+=head1 CONTRIBUTIONS, BUGS, AND CAVEATS
+
+=head2 CONTRIBUTIONS
+
+If you want to hack on PerlySense, fork the project at GitHub:
+L<https://github.com/jplindstrom/p5-Devel-PerlySense>
 
-=head1 BUGS AND CAVEATS
 
 =head2 BUG REPORTS
 
@@ -1596,7 +1602,7 @@ use strict;
 use warnings;
 
 package Devel::PerlySense;
-our $VERSION = '0.0186';
+our $VERSION = '0.0187';
 
 
 
